/*
 * Copyright (c) 1997, Purdue University
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted provided
 * that:
 *
 * (1) source distributions retain this entire copyright notice and comment,
 *     and
 * (2) distributions including binaries display the following acknowledgement:
 *
 *        "This product includes software developed by Purdue University."
 *
 *     in the documentation or other materials provided with the distribution
 *     and in all advertising materials mentioning features or use of this
 *     software.
 *
 * The name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * TCLLOG was developed by:
 *
 *      Todd M. Helfter
 *
 *      Purdue University
 *      Computing Center
 *      1408 Math Sciences Building
 *      West Lafayette, Indiana 47907-1408 U.S.A.
 *
 * For more information on TCLLOG, to report problems or to make comments,
 * send electronic mail to:
 *
 *      tmh@purdue.edu
 */

/*
 * tcllog.h
 */

#ifndef _TCLLOG_H
#define _TCLLOG_H

#include <varargs.h>
#include <sys/syslog.h>
#include <sys/types.h>

#ifdef __STDC__
#define _PROTO(s)               s
#else
#define _PROTO(s)               ()
#endif

#ifndef _TCL
#include <tcl.h>
#endif /* _TCL */

#ifdef NO_BCOPY
#define bcopy(from, to, length)    memmove((to), (from), (length))
#define bzero(buf, length)         memset((buf),(0),(length))
#endif

#define TCLLOG_VERSION "1.0"

/* _ANSI_ARGS_ should be defined by tcl.h; ignore if not defined */
#ifndef _ANSI_ARGS_
#define _ANSI_ARGS_() ()
#endif

#define EXPORT(a,b) a b
EXTERN EXPORT(int,Tcllog_Init) _ANSI_ARGS_((Tcl_Interp *interp));

int open_tcllog _ANSI_ARGS_((ClientData clientData,
                         Tcl_Interp *interp,
                         int argc,
                         char **argv));

int write_tcllog _ANSI_ARGS_((ClientData clientData,
                         Tcl_Interp *interp,
                         int argc,
                         char **argv));

int close_tcllog _ANSI_ARGS_((ClientData clientData,
                         Tcl_Interp *interp,
                         int argc,
                         char **argv));

int mask_tcllog _ANSI_ARGS_((ClientData clientData,
                         Tcl_Interp *interp,
                         int argc,
                         char **argv));

#endif /* _TCLLOG_H */
